==> hibiscus.js-1.2.1.tgz: package/modal/modal.module.js <==
import { NgModule } from '@angular/core';
import { ModalComponent } from './modal.component';
import { CommonModule } from '@angular/common';
import { ModalContentComponent } from './modal-content.component';
import { ModalBackdropComponent } from './modal-backdrop.component';
import { ModalWindowComponent } from './modal-window.component';
import { NavigationEnd, Router, RouterModule } from '@angular/router';
import { ModalService } from './modal.service';
var ModalModule = /** @class */ (function () {
    function ModalModule(router, modalService) {
        router.events.subscribe(function (event) {
            if (event instanceof NavigationEnd) {
                modalService.closeAll();
            }
        });
    }
    ModalModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        RouterModule
                    ],
                    exports: [
                        ModalBackdropComponent
                    ],
                    declarations: [
                        ModalComponent,
                        ModalContentComponent,
                        ModalBackdropComponent,
                        ModalWindowComponent
                    ],
                    entryComponents: [
                        ModalContentComponent,
                        ModalComponent,
                        ModalBackdropComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    ModalModule.ctorParameters = function () { return [
        { type: Router, },
        { type: ModalService, },
    ]; };
    return ModalModule;
}());
export { ModalModule };

==> hibiscus.js-1.2.3.tgz: package/modal/modal.module.js <==
import { NgModule } from '@angular/core';
import { ModalComponent } from './modal.component';
import { CommonModule } from '@angular/common';
import { ModalContentComponent } from './modal-content.component';
import { ModalBackdropComponent } from './modal-backdrop.component';
import { ModalWindowComponent } from './modal-window.component';
import { NavigationEnd, Router, RouterModule } from '@angular/router';
import { ModalService } from './modal.service';
var ModalModule = (function () {
    function ModalModule(router, modalService) {
        router.events.subscribe(function (event) {
            if (event instanceof NavigationEnd) {
                modalService.closeAll();
            }
        });
    }
    ModalModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        RouterModule
                    ],
                    exports: [
                        ModalBackdropComponent
                    ],
                    declarations: [
                        ModalComponent,
                        ModalContentComponent,
                        ModalBackdropComponent,
                        ModalWindowComponent
                    ],
                    entryComponents: [
                        ModalContentComponent,
                        ModalComponent,
                        ModalBackdropComponent
                    ]
                },] },
    ];
    ModalModule.ctorParameters = function () { return [
        { type: Router, },
        { type: ModalService, },
    ]; };
    return ModalModule;
}());
export { ModalModule };
